# 🌀 bluer-ai

🌀 `bluer-ai` is an implementation of 🔻 [giza](https://github.com/kamangir/giza) and a language [to speak AI](https://github.com/kamangir/bluer-south).

![image](https://github.com/kamangir/assets/blob/main/awesome-bash-cli/marquee-2024-10-26.jpg?raw=true)

# installation

```bash
pip install bluer_ai
```

Add to `bashrc`, `.bash_profile`, or the relevant startup file.

```bash
source $(python3 -m bluer_ai locate)/.abcli/bluer_ai.sh
```

# dev install

- [Amazon EC2 instances](./bluer_ai/docs/install/ec2.md)
- [Amazon SageMaker](./bluer_ai/docs/install/SageMaker.md)
- [Jetson Nano](./bluer_ai/docs/install/Jetson-Nano.md)
- [macOS](./bluer_ai/docs/install/macOS.md)
- [Raspberry Pi](./bluer_ai/docs/install/RPi.md)
- [Raspberry Pi + ROS](./bluer_ai/docs/install/RPi-ROS.md)

# aliases

[@build_README](./bluer_ai/docs/aliases/build_README.md) 
[@conda](./bluer_ai/docs/aliases/conda.md) 
[@error](./bluer_ai/docs/aliases/error.md) 
[@git](./bluer_ai/docs/aliases/git.md) 
[@gpu](./bluer_ai/docs/aliases/gpu.md) 
[@init](./bluer_ai/docs/aliases/init.md) 
[@latex](./bluer_ai/docs/aliases/latex.md) 
[@log](./bluer_ai/docs/aliases/log.md) 
[@plugins](./bluer_ai/docs/aliases/plugins.md) 
[@pypi](./bluer_ai/docs/aliases/pypi.md) 
[@random](./bluer_ai/docs/aliases/random.md) 
[@screen](./bluer_ai/docs/aliases/screen.md) 
[@seed](./bluer_ai/docs/aliases/seed.md) 
[@session](./bluer_ai/docs/aliases/session.md) 
[@ssh](./bluer_ai/docs/aliases/ssh.md) 
[@terraform](./bluer_ai/docs/aliases/terraform.md) 
[@warn](./bluer_ai/docs/aliases/warn.md) 
[@web](./bluer_ai/docs/aliases/web.md) 
[@wifi](./bluer_ai/docs/aliases/wifi.md) 

---

> 🪄 [`abcli`](https://github.com/kamangir/awesome-bash-cli) for the [Global South](https://github.com/kamangir/bluer-south).

---


[![pylint](https://github.com/kamangir/bluer-ai/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-ai/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-ai/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-ai/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-ai/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-ai/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer_ai.svg)](https://pypi.org/project/bluer_ai/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer_ai)](https://pypistats.org/packages/bluer_ai)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 🌀 [`bluer_ai-12.509.1`](https://github.com/kamangir/bluer-ai).
